This is an automated email from the ASF dual-hosted git repository.
markt pushed a commit to branch 8.5.x
in repository https://gitbox.apache.org/repos/asf/tomcat.git
The following commit(s) were added to refs/heads/8.5.x by this push:
new a479a5b Increase margin to avoid false positives
a479a5b is described below
commit a479a5b963e799eaee249e1300264d11274c69b9
Author: Mark Thomas <[email protected]>
AuthorDate: Tue Mar 3 10:08:39 2020 +0000
Increase margin to avoid false positives
---
test/org/apache/coyote/http2/TestHttp2Section_5_3.java | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/test/org/apache/coyote/http2/TestHttp2Section_5_3.java
b/test/org/apache/coyote/http2/TestHttp2Section_5_3.java
index a89a762..6c76cb4 100644
--- a/test/org/apache/coyote/http2/TestHttp2Section_5_3.java
+++ b/test/org/apache/coyote/http2/TestHttp2Section_5_3.java
@@ -168,9 +168,9 @@ public class TestHttp2Section_5_3 extends Http2TestBase {
Assert.fail("Unexpected stream: [" + output.getTrace() + "]");
}
// A value of more than 1 here is unlikely but possible depending
on
- // how threads are scheduled. This has been observed as high as 12
- // on ci.apache.org so allow a margin and use 20.
- if (data[1] > 20) {
+ // how threads are scheduled. This has been observed as high as 21
+ // on ci.apache.org so allow a margin and use 30.
+ if (data[1] > 30) {
// Larger than expected body size
Assert.fail("Larger than expected body: [" + output.getTrace()
+ "]");
}
---------------------------------------------------------------------
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]